Deep agent harness for Synaptic.
Provides an opinionated agent harness that bundles filesystem tools,
subagent spawning, skills, memory, and auto-summarization — all
implemented as AgentMiddleware.
Quick Start
ⓘ
use synaptic_deep::{create_deep_agent, DeepAgentOptions, backend::StateBackend};
let backend = Arc::new(StateBackend::new());
let options = DeepAgentOptions::new(backend);
let agent = create_deep_agent(model, options)?;
let result = agent.invoke(MessageState::with_messages(vec![
Message::human("Write hello.txt"),
])).await?;Re-exports
pub use middleware::subagent::SubAgentDef;
Modules
Structs
- Deep
Agent Options - Configuration for
create_deep_agent.
Functions
- create_
deep_ agent - Create a deep agent with the given model and options.