pub struct SubAgentMiddleware { /* private fields */ }Expand description
Middleware that provides a task tool for spawning child agents.
The task tool creates a child deep agent and invokes it with the given description.
Recursion is bounded by max_depth.
Implementations