Skill/Plugin system for Deep agents.
A Skill bundles a set of tools with metadata (SkillManifest).
The SkillRegistry manages loaded skills, collects their tools,
and aggregates system-prompt fragments.
Structs
- Skill
Manifest - Metadata about a skill.
- Skill
Registry - Registry that manages loaded skills.
Traits
- Skill
- A skill bundles a set of tools with metadata.
Functions
- discover_
skills - Discover skill manifests in a directory (looks for manifest.toml files).
- load_
manifest - Load a skill manifest from a TOML file.